@@ -33,19 +33,29 @@ class ConstantDict(object):
 
 class MsgFields(ConstantDict):
     ASNIP = "asnip"
-    ARTIFACT = "arte"
-    DOMAIN = "dom"
+    ARTIFACT = "artifact"
+    COUNTRY_CODE = "cc"
+    LAT = "lat"
+    LONG = "long"
+    DOMAIN = "domain"
     GEOIP = "geoip"
-    HOSTNAME = "host"
-    HTTP_STATUS = "httpstat"
+    HOSTNAME = "hostname"
+    HTTP_STATUS = "httpstatus"
     IP = "ip"
+    IPSET = "ipset"
     PATH = "path"
-    SCREENSHOT = "sshot"
+    SCREENSHOT = "screenshot"
     SPIDER = "spider"
     URL = "url"
     WHOIS = "whois"
     WHOIS_RAW = "raw"
 
+    TASKRESULTS = "tmoids"
+
+    TRS_META = "_trs"
+    TRS_META_JOB_ID = "jid"
+    TRS_META_TARGET_ID = "tid"
+
     META = "_"
     META_START_TIME = "stime"
     META_END_TIME = "etime"
@@ -54,3 +64,19 @@ class MsgFields(ConstantDict):
     META_VERSION = "v"
     META_ERR = "e"
     META_MSG = "m"
+
+
+class MsgErrs(ConstantDict):
+    INPUT_INCORRECT_FORMAT = "INPUT_INCORRECT_FORMAT::{0}"
+    INPUT_MISSING = "INPUT_MISSING::{0}"
+
+    HOSTNAME_UNRESOLVABLE = "HOSTNAME_UNRESOLVABLE::{0}"
+    HOSTNAME_INVALID = "HOSTNAME_INVALID::{0}"
+
+    RESULT_INVALID = "RESULT_INVALID::{0}"
+
+    UNSPECIFIED_ERROR = "UNSPECIFIED_ERROR::{0}"
+
+    URL_INVALID = "URL_INVALID::{0}"
+    URL_TIMEOUT = "URL_TIMEOUT::{0}"
+    URL_UNFETCHABLE = "URL_UNFETCHABLE::{0}"
