@@ -2,12 +2,11 @@
 
 import unittest
 import json
-import colander
 
 from ..taskresult import TaskResult, TaskSeed, SEED_VERSION
-from ..fields import MsgFields as F
+from ..fields import MsgFields as F, MsgErrs as MERR
 from ..exceptions import ValidationError
-from ..schemas import _BaseTaskSchema
+from ..schemas import build_schema
 
 
 class TestTaskResult(unittest.TestCase):
@@ -73,12 +72,10 @@ class TestTaskResult(unittest.TestCase):
         tr.add("a", "Here are my results")
         self.assertEqual(tr.get_data("a"), "Here are my results")
 
-    @unittest.skip
     def test_add_nested_data(self):
         tr = TaskResult(self.task_name, "1.1.1", 10098)
         tr.add("results", {"a": "Nested"})
         self.assertEqual(tr.get_data("results"), {"a": "Nested"})
-        self.assertEqual(tr["results"], {"a": "Nested"})
 
     def test_missing_data(self):
         tr = TaskResult(self.task_name, "1.1.1", 10098)
@@ -192,16 +189,19 @@ class TestTaskResult(unittest.TestCase):
     def test_schema_fail(self):
         tr = TaskResult(self.task_name, "1.1.1", 100)
         tr.add("nosuch", "My whois data")
-        try:
-            tr.finish()
-        except ValidationError:
-            assert(True)
-        else:
-            assert(False)
+        tr.finish()
+
+        self.assertFalse(tr.success)
+        self.assertTrue(tr.err.startswith(MERR.RESULT_INVALID.format("")))
 
     def test_custom_schema(self):
-        class TestCustomSchema(_BaseTaskSchema):
-            z = colander.SchemaNode(colander.String(), name="z")
+        TestCustomSchema = build_schema({
+            "properties": {
+                "z": {"type": "string"}
+            },
+            "required": ["z"]
+        })
+
         tr = TaskResult(self.task_name, "1.1.1", 100, schema=TestCustomSchema)
         tr.add("z", "My whois data")
         tr.finish()
@@ -209,18 +209,21 @@ class TestTaskResult(unittest.TestCase):
         self.assertEqual(tr.get_data("z"), "My whois data")
 
     def test_custom_schema_invalid(self):
-        class TestCustomInvalidSchema(_BaseTaskSchema):
-            z = colander.SchemaNode(colander.String(), name="z")
+        TestCustomInvalidSchema = build_schema({
+            "properties": {
+                "z": {"type": "string"}
+            },
+            "required": ["z"]
+        })
 
         tr = TaskResult(self.task_name, "1.1.1", 100,
                         schema=TestCustomInvalidSchema)
         tr.add("y", "My whois data")
-        try:
-            tr.finish()
-        except ValidationError:
-            assert(True)
-        else:
-            assert(False)
+        tr.finish()
+
+
+        self.assertFalse(tr.success)
+        self.assertTrue(tr.err.startswith(MERR.RESULT_INVALID.format("")))
 
 
 class TestTaskSeed(unittest.TestCase):
